@@ -11,15 +11,12 @@ class CheckNamedTask(StandardBase):
 
     def check(self, candidate, settings):
         tasks, errors = self.get_normalized_tasks(candidate, settings)
-        nameless_tasks = [
-            "meta", "debug", "include_role", "import_role", "include_tasks", "import_tasks",
-            "include_vars", "block"
-        ]
+        exclude_modules = settings["ansible"]["named-task"]["exclude"]
 
         if not errors:
             for task in tasks:
                 module = task["action"]["__ansible_module__"]
-                if ("name" not in task or not task["name"]) and module not in nameless_tasks:
+                if ("name" not in task or not task["name"]) and module not in exclude_modules:
                     errors.append(
                         self.Error(task["__line__"], self.helptext.format(module=module))
                     )
