@@ -120,6 +120,7 @@ class Settings(object):
                 "standards": [],
                 "filter": [],
                 "exclude_filter": [],
+                "warning_filter": ["ANSIBLE9999"],
                 "ignore_dotfiles": True,
                 "exclude_files": [],
                 "version": ""
@@ -135,6 +136,21 @@ class Settings(object):
                     "max-spaces-inside": 1,
                 },
                 "literal-bools": ["True", "False", "yes", "no"],
+                "named-task": {
+                    "exclude": [
+                        "meta",
+                        "debug",
+                        "block",
+                        "include_role",
+                        "import_role",
+                        "include_tasks",
+                        "import_tasks",
+                        "include_vars",
+                    ],
+                },
+                "native-yaml": {
+                    "exclude": [],
+                },
             },
             "yamllint": {
                 "empty-lines": {
